==> qmmp-1.1.9-1-src.tar.xz: qmmp-1.1.9/src/plugins/Input/sid/translations/sid_plugin_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="gl_ES">
<context>
    <name>DecoderSIDFactory</name>
    <message>
        <location filename="../decodersidfactory.cpp" line="77"/>
        <source>SID Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="79"/>
        <source>SID Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="133"/>
        <source>About SID Audio Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="134"/>
        <source>Qmmp SID Audio Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="135"/>
        <source>This plugin plays Commodore 64 music files using libsidplayfp library</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="136"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>SID Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Fast resampling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>Sample rate:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="69"/>
        <source>HVSC database file:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <source>Resampling method:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="93"/>
        <source>Defaults song length, sec:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="100"/>
        <source>Enable HVSC song length database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="107"/>
        <source>Emulation:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="41"/>
        <source>44100 Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="42"/>
        <source>48000 Hz</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp-1.1.12-2-src.tar.xz: qmmp-1.1.12/src/plugins/Input/sid/translations/sid_plugin_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="gl_ES">
<context>
    <name>DecoderSIDFactory</name>
    <message>
        <location filename="../decodersidfactory.cpp" line="77"/>
        <source>SID Plugin</source>
        <translation>Plugin SID</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="79"/>
        <source>SID Files</source>
        <translation>Arquivos SID</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="133"/>
        <source>About SID Audio Plugin</source>
        <translation>Acerca do plugin SID Audio</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="134"/>
        <source>Qmmp SID Audio Plugin</source>
        <translation>Plugin Qmmp SID Audio</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="135"/>
        <source>This plugin plays Commodore 64 music files using libsidplayfp library</source>
        <translation>Este plugin reproduce os arquivos de música da Commodore 64 usando a biblioteca libsidplayfp</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="136"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Escrito por: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>SID Plugin Settings</source>
        <translation>Configuracións do plugin SID</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Fast resampling</source>
        <translation>Remostreo rápido</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>Sample rate:</source>
        <translation>Taxa de mostra:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="69"/>
        <source>HVSC database file:</source>
        <translation>Arquivo da base de datos HVSC:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <source>Resampling method:</source>
        <translation>Método de remostreo:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="93"/>
        <source>Defaults song length, sec:</source>
        <translation>Defaults song length, sec:
Lonxitude por defecto da canción, seg:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="100"/>
        <source>Enable HVSC song length database</source>
        <translation>Habilitar base de datos HVSC duración cancións</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="107"/>
        <source>Emulation:</source>
        <translation>Emulación:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="41"/>
        <source>44100 Hz</source>
        <translation>44100 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="42"/>
        <source>48000 Hz</source>
        <translation>48000 Hz</translation>
    </message>
</context>
</TS>
